summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorIan Abbott <abbotti@mev.co.uk>2026-01-30 19:47:27 +0300
committerGreg Kroah-Hartman <gregkh@linuxfoundation.org>2026-04-02 16:49:36 +0300
commitcb51837eeeddac2da41f4c202597c534bb9d8dc9 (patch)
tree4e0fa21cc854fabca6c96d74a12eb44348e879d2
parent241cb8dee0f83856c728f4fe2c29e331386c92f2 (diff)
downloadlinux-cb51837eeeddac2da41f4c202597c534bb9d8dc9.tar.xz
comedi: 8255: Add some I/O base address sanity checks
The "8255" driver allows a COMEDI device to be constructed from one or more 8255 chips, each at an I/O port base address specified by the admin-supplied configuration options (`it->options[]`). Currently, the driver allows any I/O base addresses to be specified as long as the I/O regions can be reserved, and it converts the specified `int` option values holding the base address to `unsigned long`. It doesn't make sense to allow base addresses that are not aligned to 4-byte boundaries because the hardware register addresses would not be decoded properly, so add a check for valid alignment. Convert the option values that specify the base addresses from `int` to `unsigned int` instead of `unsigned long` so they end up the same on 32-bit and 64-bit systems. Signed-off-by: Ian Abbott <abbotti@mev.co.uk> Link: https://patch.msgid.link/20260130170416.49994-3-abbotti@mev.co.uk Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
-rw-r--r--drivers/comedi/drivers/8255.c10
1 files changed, 6 insertions, 4 deletions
diff --git a/drivers/comedi/drivers/8255.c b/drivers/comedi/drivers/8255.c
index 5f70938b4477..ff45248ebb29 100644
--- a/drivers/comedi/drivers/8255.c
+++ b/drivers/comedi/drivers/8255.c
@@ -47,7 +47,7 @@ static int dev_8255_attach(struct comedi_device *dev,
struct comedi_devconfig *it)
{
struct comedi_subdevice *s;
- unsigned long iobase;
+ unsigned int iobase;
int ret;
int i;
@@ -70,13 +70,15 @@ static int dev_8255_attach(struct comedi_device *dev,
iobase = it->options[i];
/*
* __comedi_request_region() does not set dev->iobase.
*
* For 8255 devices that are manually attached using
* comedi_config, the 'iobase' is the actual I/O port
- * base address of the chip.
+ * base address of the chip. It should be aligned on
+ * a 4-byte boundary.
*/
- ret = __comedi_request_region(dev, iobase, I8255_SIZE);
+ ret = __comedi_check_request_region(dev, iobase, I8255_SIZE,
+ 0, UINT_MAX, 4);
if (ret)
return ret;
ret = subdev_8255_io_init(dev, s, iobase);
@@ -70,13 +70,15 @@ static int dev_8255_attach(struct comedi_device *dev,
iobase = it->options[i];
/*
- * __comedi_request_region() does not set dev->iobase.
+ * __comedi_check_request_region() does not set dev->iobase.
*
* For 8255 devices that are manually attached using